{% extends "djhcup_base.html" %}


{% block title %}{{ title }}{% endblock %}


{% block content %}
    <form method="POST" class="right-align-labels">
        {% csrf_token %}
        <ol>
            {{ form.as_ul }}
        <li><input type="submit" value="Log in" /></li>
        </ol>
    </form>
{% endblock %}
